import threading


class ThreadJob(threading.Thread):
    def __init__(self, callback, event, interval):
        """runs the callback function after interval seconds

        :param callback:  callback function to invoke
        :param event: external event for controlling the update operation
        :param interval: time in seconds after which are required to fire the callback
        :type callback: function
        :type interval: int
        """
        self.callback = callback
        self.event = event
        self.interval = interval
        super(ThreadJob, self).__init__()

    def run(self):
        while not self.event.wait(self.interval):
            self.callback()



from typing import Optional, List

from fastapi_camelcase import CamelModel


class CityAlias(CamelModel):
    id: Optional[str]
    country_iso3: Optional[str]
    province_code: Optional[str]
    official_name_en: Optional[str]
    official_name_fr: Optional[str]
    clli_code: Optional[str]
    st_vec_req: Optional[str]
    serv_addr_edits: Optional[str]
    legacy_txt: Optional[str]
    leca_cd: Optional[str]
    alias: Optional[List[str]] = []
